BlockingScope

Enum BlockingScope 

pub enum BlockingScope {
    NotBlocking,
    BlocksAction,
    BlocksContinuation,
    Custom(&'static str),
}
What a hook can block when a handler returns a blocking result.

Variants



NotBlocking

The event is not blocking.



BlocksAction

The hook can block the action that has not yet run.



BlocksContinuation

The hook can block continuation after an action or turn.



Custom(&'static str)

Harness-specific blocking semantics documented by the adapter.