pub struct PayloadField {
pub name: &'static str,
pub value_type: PayloadValueType,
pub required: bool,
pub description: &'static str,
}Expand description
A field expected in a hook payload.
Fields
name: &'static strField name as it appears in the canonical payload descriptor.
value_type: PayloadValueTypeField value type.
required: boolWhether the field is required for the canonical event.
description: &'static strHuman-facing field description.